@@ -38,6 +38,14 @@ def language_selector(context):
 def column_width(value):
     return 12 // len(list(value))
 
+@register.filter(name='form_fieldset_column_width')
+def form_fieldset_column_width(form):
+    def max_line(fieldset):
+        return max([len(list(line)) for line in fieldset])
+
+    width = max([max_line(fieldset) for fieldset in form])
+    return 12 // width
+
 @register.filter(name='fieldset_column_width')
 def fieldset_column_width(fieldset):
     width = max([len(list(line)) for line in fieldset])
